==> django-kmuhelper-1.4.tar.gz: django-kmuhelper-1.4/kmuhelper/emails/views.py <==
from django.contrib import messages
from django.contrib.auth.decorators import login_required, permission_required
from django.http import HttpResponse
from django.shortcuts import redirect
from django.urls import reverse, reverse_lazy

from kmuhelper.decorators import require_object, confirm_action
from kmuhelper.emails.models import EMail, Attachment, EMailTemplate
from kmuhelper.utils import render_error

#####

# EMail views


@login_required(login_url=reverse_lazy("admin:login"))
@permission_required("kmuhelper.send_email")
@require_object(EMail)
@confirm_action("E-Mail Nachricht senden")
def email_send(request, obj):
    if obj.is_valid():
        success = obj.send()
        if success:
            messages.success(request, "E-Mail wurde versendet!")
        else:
            messages.error(request, "E-Mail konnte nicht gesendet werden!")
    return redirect(reverse("admin:kmuhelper_email_change", args=[obj.pk]))


@login_required(login_url=reverse_lazy("admin:login"))
@permission_required("kmuhelper.send_email")
@require_object(EMail)
@confirm_action("E-Mail Nachricht ERNEUT senden")
def email_resend(request, obj):
    if obj.is_valid(request):
        success = obj.send()
        if success:
            messages.success(request, "E-Mail wurde erneut versendet!")
        else:
            messages.error(request, "E-Mail konnte nicht gesendet werden!")
    return redirect(reverse("admin:kmuhelper_email_change", args=[obj.pk]))


@login_required(login_url=reverse_lazy("admin:login"))
@permission_required("kmuhelper.view_email")
@require_object(EMail)
def email_preview(request, obj):
    if obj.is_valid(request):
        return HttpResponse(obj.render(online=True))
    return redirect(reverse("admin:kmuhelper_email_change", args=[obj.pk]))


# Public views


@require_object(EMail, show_errorpage=True)
def email_view(request, obj):
    """Render an email for online viewing"""

    token_received = request.GET.get("token", None)
    token_stored = str(obj.token)

    if request.user.has_perm("kmuhelper.view_email") or (token_received == token_stored):
        if obj.is_valid():
            return HttpResponse(obj.render(online=True))

        messages.warning(
            request, "Diese E-Mail kann zurzeit leider nicht angezeigt werden.")
    else:
        messages.error(request, "Du hast keinen Zugriff auf diese E-Mail!")

    return render_error(request)


# EMailAttachment views


@login_required(login_url=reverse_lazy("admin:login"))
@permission_required("kmuhelper.download_attachment")
@require_object(Attachment)
def attachment_download(request, obj):
    download = not "preview" in request.GET
    return obj.get_file_response(download=download)


# Public views


@require_object(Attachment, show_errorpage=True)
def attachment_view(request, obj):
    """Render an attachment for online viewing"""

    token_received = request.GET.get("token", None)
    token_stored = str(obj.token)

    if request.user.has_perm("kmuhelper.download_attachment") or (token_received == token_stored):
        download = "download" in request.GET
        return obj.get_file_response(download=download)

    messages.error(request, "Du hast keinen Zugriff auf diesen E-Mail Anhang!")
    return render_error(request)


# EMailTemplate Views


@login_required(login_url=reverse_lazy("admin:login"))
@permission_required(["kmuhelper.view_emailtemplate"])
def emailtemplate_savevars(request):
    """Save variables into session for usage in template"""

    data = request.GET.dict()
    request.session["emailtemplate-vars"] = data

    messages.success(
        request, f"Folgende Daten wurden gespeichert, um die nächste Vorlage auszufüllen: {data}")
    return redirect(reverse("admin:kmuhelper_emailtemplate_changelist"))


@login_required(login_url=reverse_lazy("admin:login"))
@permission_required(["kmuhelper.view_emailtemplate"])
def emailtemplate_resetvars(request):
    """Reset saved session variables for email templates"""

    if "emailtemplate-vars" in request.session:
        del request.session["emailtemplate-vars"]

    messages.success(
        request, "Gespeicherte Daten wurden gelöscht!")
    return redirect(reverse("admin:kmuhelper_emailtemplate_changelist"))


@login_required(login_url=reverse_lazy("admin:login"))
@permission_required(["kmuhelper.view_emailtemplate", "kmuhelper.add_email"])
@require_object(EMailTemplate)
def emailtemplate_use(request, obj):
    """Use a template"""

    savedvars = request.session.pop("emailtemplate-vars", dict())
    requestvars = request.GET.dict()
    data = {**savedvars, **requestvars}

    mail = obj.create_mail(data)

    messages.success(
        request, f"Vorlage wurde mit folgenden Daten ausgefüllt: {data}")
    return redirect(reverse("admin:kmuhelper_email_change", args=[mail.pk]))

==> django-kmuhelper-1.4.1.tar.gz: django-kmuhelper-1.4.1/kmuhelper/emails/views.py <==
from django.contrib import messages
from django.contrib.auth.decorators import login_required, permission_required
from django.http import HttpResponse
from django.shortcuts import redirect, render
from django.urls import reverse, reverse_lazy

from kmuhelper.decorators import require_object, confirm_action
from kmuhelper.emails.models import EMail, Attachment, EMailTemplate
from kmuhelper.utils import render_error

#####

# EMail views


@login_required(login_url=reverse_lazy("admin:login"))
@permission_required("kmuhelper.send_email")
@require_object(EMail)
@confirm_action("E-Mail Nachricht senden")
def email_send(request, obj):
    if obj.is_valid():
        success = obj.send()
        if success:
            messages.success(request, "E-Mail wurde versendet!")
        else:
            messages.error(request, "E-Mail konnte nicht gesendet werden!")
    return redirect(reverse("admin:kmuhelper_email_change", args=[obj.pk]))


@login_required(login_url=reverse_lazy("admin:login"))
@permission_required("kmuhelper.send_email")
@require_object(EMail)
@confirm_action("E-Mail Nachricht ERNEUT senden")
def email_resend(request, obj):
    if obj.is_valid(request):
        success = obj.send()
        if success:
            messages.success(request, "E-Mail wurde erneut versendet!")
        else:
            messages.error(request, "E-Mail konnte nicht gesendet werden!")
    return redirect(reverse("admin:kmuhelper_email_change", args=[obj.pk]))


@login_required(login_url=reverse_lazy("admin:login"))
@permission_required("kmuhelper.view_email")
@require_object(EMail)
def email_preview(request, obj):
    if obj.is_valid(request):
        return HttpResponse(obj.render(online=True))
    return redirect(reverse("admin:kmuhelper_email_change", args=[obj.pk]))


# Public views


@require_object(EMail, show_errorpage=True)
def email_view(request, obj):
    """Render an email for online viewing"""

    token_received = request.GET.get("token", None)
    token_stored = str(obj.token)

    if request.user.has_perm("kmuhelper.view_email") or (token_received == token_stored):
        if obj.is_valid():
            return HttpResponse(obj.render(online=True))

        messages.warning(
            request, "Diese E-Mail kann zurzeit leider nicht angezeigt werden.")
    else:
        messages.error(request, "Du hast keinen Zugriff auf diese E-Mail!")

    return render_error(request)


# EMailAttachment views


@login_required(login_url=reverse_lazy("admin:login"))
@permission_required("kmuhelper.download_attachment")
@require_object(Attachment)
def attachment_download(request, obj):
    download = not "preview" in request.GET
    return obj.get_file_response(download=download)


# Public views


@require_object(Attachment, show_errorpage=True)
def attachment_view(request, obj):
    """Render an attachment for online viewing"""

    token_received = request.GET.get("token", None)
    token_stored = str(obj.token)

    if request.user.has_perm("kmuhelper.download_attachment") or (token_received == token_stored):
        download = "download" in request.GET
        return obj.get_file_response(download=download)

    messages.error(request, "Du hast keinen Zugriff auf diesen E-Mail-Anhang!")
    return render_error(request)


# EMailTemplate Views


@login_required(login_url=reverse_lazy("admin:login"))
@permission_required(["kmuhelper.view_emailtemplate"])
def emailtemplate_savevars(request):
    """Save variables into session for usage in template"""

    data = request.GET.dict()
    request.session["emailtemplate-vars"] = data

    messages.success(
        request, f"Folgende Daten wurden gespeichert, um die nächste Vorlage auszufüllen: {data}")
    return redirect(reverse("admin:kmuhelper_emailtemplate_changelist"))


@login_required(login_url=reverse_lazy("admin:login"))
@permission_required(["kmuhelper.view_emailtemplate"])
def emailtemplate_resetvars(request):
    """Reset saved session variables for email templates"""

    if "emailtemplate-vars" in request.session:
        del request.session["emailtemplate-vars"]

    messages.success(
        request, "Gespeicherte Daten wurden gelöscht!")
    return redirect(reverse("admin:kmuhelper_emailtemplate_changelist"))


@login_required(login_url=reverse_lazy("admin:login"))
@permission_required(["kmuhelper.view_emailtemplate", "kmuhelper.add_email"])
@require_object(EMailTemplate)
def emailtemplate_use(request, obj):
    """Use a template"""

    savedvars = request.session.pop("emailtemplate-vars", dict())
    requestvars = request.GET.dict()
    data = {**savedvars, **requestvars}

    mail = obj.create_mail(data)

    messages.success(
        request, f"Vorlage wurde mit folgenden Daten ausgefüllt: {data}")
    return redirect(reverse("admin:kmuhelper_email_change", args=[mail.pk]))


# Custom fake admin

@login_required(login_url=reverse_lazy("admin:login"))
def email_index(request):
    return render(request, 'admin/kmuhelper/_special/emails/app_index.html', {
        'app_label': 'kmuhelper',
        'app_list': [{
            'app_label': 'kmuhelper',
            'app_url': reverse('kmuhelper:email-index'),
            'has_module_perms': True,
            'models': [
                {
                    'add_url': reverse("admin:kmuhelper_email_add"),
                    'admin_url': reverse("admin:kmuhelper_email_changelist"),
                    'name': "E-Mails",
                    'perms': {
                        'add': request.user.has_perm("kmuhelper.add_email"),
                        'change': request.user.has_perm("kmuhelper.change_email"),
                        'delete': request.user.has_perm("kmuhelper.delete_email"),
                        'view': request.user.has_perm("kmuhelper.view_email")},
                    'view_only': False
                },
                {
                    'add_url': reverse("admin:kmuhelper_attachment_add"),
                    'admin_url': reverse("admin:kmuhelper_attachment_changelist"),
                    'name': "E-Mail-Anhänge",
                    'perms': {
                        'add': request.user.has_perm("kmuhelper.add_attachment"),
                        'change': request.user.has_perm("kmuhelper.change_attachment"),
                        'delete': request.user.has_perm("kmuhelper.delete_attachment"),
                        'view': request.user.has_perm("kmuhelper.view_attachment")},
                    'view_only': False
                },
                {
                    'add_url': reverse("admin:kmuhelper_emailtemplate_add"),
                    'admin_url': reverse("admin:kmuhelper_emailtemplate_changelist"),
                    'name': "E-Mail-Vorlagen",
                    'perms': {
                        'add': request.user.has_perm("kmuhelper.add_emailtemplate"),
                        'change': request.user.has_perm("kmuhelper.change_emailtemplate"),
                        'delete': request.user.has_perm("kmuhelper.delete_emailtemplate"),
                        'view': request.user.has_perm("kmuhelper.view_emailtemplate")},
                    'view_only': False
                },
            ],
            'name': 'KMUHelper E-Mails'
        }],
        'has_permission': True,
        'is_nav_sidebar_enabled': False,
        'is_popup': False,
        'title': 'KMUHelper E-Mails',
    })
